@@ -55,7 +55,6 @@
 
 /* Defines */
 #define PLUG_IN_NAME        "plug_in_wr_huesat"
-#define PLUG_IN_VERSION     "v1.3 (2004/01/15)"
 #define PLUG_IN_IMAGE_TYPES "RGB*, GRAY*"
 #define PLUG_IN_AUTHOR      "Wolfgang Hofer (hof@gimp.org)"
 #define PLUG_IN_COPYRIGHT   "Wolfgang Hofer"
@@ -64,6 +63,7 @@
 #define PLUG_IN_ITER_NAME       "plug_in_wr_huesat_Iterator"
 #define PLUG_IN_DATA_ITER_FROM  "plug_in_wr_huesat_ITER_FROM"
 #define PLUG_IN_DATA_ITER_TO    "plug_in_wr_huesat_ITER_TO"
+#define PLUG_IN_HELP_ID         "plug-in-wr-huesat"
 
 
 
@@ -246,6 +246,8 @@ query (void)
   static GimpParamDef *return_iter = NULL;
   static int nreturn_iter = 0;
 
+  gimp_plugin_domain_register (GETTEXT_PACKAGE, LOCALEDIR);
+
   /* the actual installation of the bend plugin */
   gimp_install_procedure (PLUG_IN_NAME,
                           PLUG_IN_DESCRIPTION,
@@ -257,8 +259,8 @@ query (void)
                           ,
                           PLUG_IN_AUTHOR,
                           PLUG_IN_COPYRIGHT,
-                          PLUG_IN_VERSION,
-                          N_("<Image>/Video/Layer/Colors/Hue-Saturation..."),
+                          GAP_VERSION_WITH_DATE,
+                          N_("Hue-Saturation..."),
                           PLUG_IN_IMAGE_TYPES,
                           GIMP_PLUGIN,
                           nargs,
@@ -273,12 +275,23 @@ query (void)
                           "",
                           PLUG_IN_AUTHOR,
                           PLUG_IN_COPYRIGHT,
-                          PLUG_IN_VERSION,
+                          GAP_VERSION_WITH_DATE,
                           NULL,    /* do not appear in menus */
                           NULL,
                           GIMP_PLUGIN,
                           nargs_iter, nreturn_iter,
                           args_iter, return_iter);
+
+  {
+    /* Menu names */
+    const char *menupath_image_video_layer_colors = N_("<Image>/Video/Layer/Colors/");
+
+    //gimp_plugin_menu_branch_register("<Image>", "Video");
+    //gimp_plugin_menu_branch_register("<Image>/Video", "Layer");
+    //gimp_plugin_menu_branch_register("<Image>/Video/Layer", "Colors");
+
+    gimp_plugin_menu_register (PLUG_IN_NAME, menupath_image_video_layer_colors);
+  }
 }
 
 
@@ -569,7 +582,7 @@ do_dialog (wr_huesat_val_t *cuvals)
   /*  The dialog1 and main vbox  */
   dialog1 = gimp_dialog_new (_("Hue-Saturation"), "hue_saturation_wrapper",
                                NULL, 0,
-			       gimp_standard_help_func, NULL, /* "filters/color/wrapper.html" */
+			       gimp_standard_help_func, PLUG_IN_HELP_ID,
 
                                GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                GTK_STOCK_OK,     GTK_RESPONSE_OK,
@@ -602,7 +615,7 @@ do_dialog (wr_huesat_val_t *cuvals)
 
 
   /* the frame */
-  frame1 = gtk_frame_new (_("Hue / Lightness / Saturation Adjustments "));
+  frame1 = gimp_frame_new (_("Hue / Lightness / Saturation Adjustments "));
 
   gtk_widget_show (frame1);
   gtk_box_pack_start (GTK_BOX (dialog_vbox1), frame1, TRUE, TRUE, 0);
