@@ -54,7 +54,6 @@
 
 /* Defines */
 #define PLUG_IN_NAME        "plug_in_wr_color_levels"
-#define PLUG_IN_VERSION     "v1.3 (2004/01/15)"
 #define PLUG_IN_IMAGE_TYPES "RGB*, GRAY*"
 #define PLUG_IN_AUTHOR      "Wolfgang Hofer (hof@gimp.org)"
 #define PLUG_IN_COPYRIGHT   "Wolfgang Hofer"
@@ -63,6 +62,7 @@
 #define PLUG_IN_ITER_NAME       "plug_in_wr_color_levels_Iterator"
 #define PLUG_IN_DATA_ITER_FROM  "plug_in_wr_color_levels_ITER_FROM"
 #define PLUG_IN_DATA_ITER_TO    "plug_in_wr_color_levels_ITER_TO"
+#define PLUG_IN_HELP_ID         "plug-in-wr-color-levels"
 
 
 
@@ -255,6 +255,8 @@ query (void)
   static GimpParamDef *return_iter = NULL;
   static int nreturn_iter = 0;
 
+  gimp_plugin_domain_register (GETTEXT_PACKAGE, LOCALEDIR);
+
   /* the actual installation of the bend plugin */
   gimp_install_procedure (PLUG_IN_NAME,
                           PLUG_IN_DESCRIPTION,
@@ -266,8 +268,8 @@ query (void)
                           ,
                           PLUG_IN_AUTHOR,
                           PLUG_IN_COPYRIGHT,
-                          PLUG_IN_VERSION,
-                          N_("<Image>/Video/Layer/Colors/Levels..."),
+                          GAP_VERSION_WITH_DATE,
+                          N_("Levels..."),
                           PLUG_IN_IMAGE_TYPES,
                           GIMP_PLUGIN,
                           nargs,
@@ -282,12 +284,22 @@ query (void)
                           "",
                           PLUG_IN_AUTHOR,
                           PLUG_IN_COPYRIGHT,
-                          PLUG_IN_VERSION,
+                          GAP_VERSION_WITH_DATE,
                           NULL,    /* do not appear in menus */
                           NULL,
                           GIMP_PLUGIN,
                           nargs_iter, nreturn_iter,
                           args_iter, return_iter);
+  {
+    /* Menu names */
+    const char *menupath_image_video_layer_colors = N_("<Image>/Video/Layer/Colors/");
+
+    //gimp_plugin_menu_branch_register("<Image>", "Video");
+    //gimp_plugin_menu_branch_register("<Image>/Video", "Layer");
+    //gimp_plugin_menu_branch_register("<Image>/Video/Layer", "Colors");
+
+    gimp_plugin_menu_register (PLUG_IN_NAME, menupath_image_video_layer_colors);
+  }
 }
 
 
@@ -584,7 +596,7 @@ do_dialog (wr_levels_val_t *cuvals)
   /*  The dialog1 and main vbox  */
   dialog1 = gimp_dialog_new (_("Color Levels"), "levels_wrapper",
                                NULL, 0,
-			       gimp_standard_help_func, NULL, /* "filters/color/wrapper.html" */
+			       gimp_standard_help_func, PLUG_IN_HELP_ID, 
 
                                GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                GTK_STOCK_OK,     GTK_RESPONSE_OK,
@@ -609,7 +621,7 @@ do_dialog (wr_levels_val_t *cuvals)
 
 
   /* the frame */
-  frame1 = gtk_frame_new (_("Color Levels  Adjustments "));
+  frame1 = gimp_frame_new (_("Color Levels  Adjustments "));
   gtk_widget_show (frame1);
   gtk_box_pack_start (GTK_BOX (dialog_vbox1), frame1, TRUE, TRUE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (frame1), 2);
@@ -633,27 +645,27 @@ do_dialog (wr_levels_val_t *cuvals)
 
   /* Channel the radio buttons */
   radiobutton1 = gtk_radio_button_new_with_label (vbox1_group, _("Master"));
-  vbox1_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton1));
+  vbox1_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton1));
   gtk_widget_show (radiobutton1);
   gtk_box_pack_start (GTK_BOX (vbox1), radiobutton1, FALSE, FALSE, 0);
 
   radiobutton2 = gtk_radio_button_new_with_label (vbox1_group, _("Red"));
-  vbox1_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton2));
+  vbox1_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton2));
   gtk_widget_show (radiobutton2);
   gtk_box_pack_start (GTK_BOX (vbox1), radiobutton2, FALSE, FALSE, 0);
 
   radiobutton3 = gtk_radio_button_new_with_label (vbox1_group, _("Green"));
-  vbox1_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton3));
+  vbox1_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton3));
   gtk_widget_show (radiobutton3);
   gtk_box_pack_start (GTK_BOX (vbox1), radiobutton3, FALSE, FALSE, 0);
 
   radiobutton4 = gtk_radio_button_new_with_label (vbox1_group, _("Blue"));
-  vbox1_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton4));
+  vbox1_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton4));
   gtk_widget_show (radiobutton4);
   gtk_box_pack_start (GTK_BOX (vbox1), radiobutton4, FALSE, FALSE, 0);
 
   radiobutton5 = gtk_radio_button_new_with_label (vbox1_group, _("Alpha"));
-  vbox1_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton5));
+  vbox1_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton5));
   gtk_widget_show (radiobutton5);
   gtk_box_pack_start (GTK_BOX (vbox1), radiobutton5, FALSE, FALSE, 0);
 
